@@ -17,7 +17,7 @@ from typing import (
     Union,
 )
 
-from pdm.pep517._vendor import toml
+from pdm.pep517._vendor import tomli
 from pdm.pep517._vendor.packaging.requirements import Requirement
 from pdm.pep517._vendor.packaging.version import Version
 from pdm.pep517.license import license_lookup
@@ -91,10 +91,11 @@ class Metadata:
 
     def _read_pyproject(self) -> None:
         try:
-            data = toml.loads(self.filepath.read_text(encoding="utf-8"))
+            with self.filepath.open("rb") as f:
+                data = tomli.load(f)
         except FileNotFoundError:
             raise ProjectError("pyproject.toml does not exist.")
-        except toml.TomlDecodeError:
+        except tomli.TOMLDecodeError:
             raise ProjectError("The project's pyproject.toml is not valid.")
         else:
             if "tool" in data and "pdm" in data["tool"]:
@@ -137,9 +138,15 @@ class Metadata:
             with self.filepath.parent.joinpath(version_source).open(
                 encoding="utf-8"
             ) as fp:
-                return re.findall(
-                    r"^__version__\s*=\s*[\"'](.+?)[\"']\s*$", fp.read(), re.M
-                )[0]
+                match = re.search(
+                    r"^__version__\s*=\s*[\"'](.+?)[\"']\s*(?:#.*)?$", fp.read(), re.M
+                )
+                if not match:
+                    raise ProjectError(
+                        f"Can't find version in file {version_source}, "
+                        "it should appear as `__version__ = 'a.b.c'`."
+                    )
+                return match.group(1)
         elif dynamic_version.get("use_scm", False):
             return get_version_from_scm(self.filepath.parent)
         else:
@@ -296,10 +303,10 @@ class Metadata:
     @property
     def editable_backend(self) -> str:
         """Currently only two backends are supported:
-        - editables: Proxy modules via editables(default)
-        - path: the legacy .pth file method
+        - editables: Proxy modules via editables
+        - path: the legacy .pth file method(default)
         """
-        return self._tool_settings.get("editable-backend", "editables")
+        return self._tool_settings.get("editable-backend", "path")
 
     def _convert_dependencies(self, deps: List[str]) -> List[str]:
         return list(filter(None, map(ensure_pep440_req, deps)))
